# EZTorch

Utility functions and fluent interface for PyTorch tensors and modules

# Installation

**PIP**
```bash
pip install git+https://github.com/ichko/ez-torch
```

**From repo**
```bash
git clone https://github.com/ichko/ez-torch
cd ez-torch
poetry install
poetry run pytest
```

# Examples
...
